### Usage

```js static
import InputPassword from '@meta-vue/input-password';

export default {
	...
	components: { InputPassword }
	...
};
```

### Examples

##### Example with default icons

```js
new Vue({
  data() {
    return {
      password: ''
    };
  },
  methods: {
    onValidation(validation, fieldName) {
      console.warn(`${fieldName} validation`, validation);
    }
  },
  template: `
    <InputPassword
      id="password1"
      label="Password example"
      name="password1"
      placeholder="Type your password"
      @validation="onValidation"
      v-model="password"
    />
  `
});
```

##### Example with slots (custom html for toggle input type)
You can pass whatever you like to be the custom html for toggling the input type.
To do this you need to pass slots with name "textTypeHtml" and "passwordTypeHtml" and it will override the default icons.
```js
new Vue({
  data() {
    return {
      password: ''
    };
  },
  methods: {
    onValidation(validation, fieldName) {
      console.warn(`${fieldName} validation`, validation);
    }
  },
  template: `
    <InputPassword
      id="password"
      label="Password example"
      name="password"
      placeholder="Type your password"
      @validation="onValidation"
      v-model="password"
    >
      <span class="mdi mdi-toggle-switch-off" slot="textTypeHtml"></span>
      <span class="mdi mdi-toggle-switch-outline" slot="passwordTypeHtml"></span>
    </InputPassword>
  `
});
```